@@ -81,7 +81,10 @@ class Camera(BaseCamera):
         # i need these to be in globals() ----evaluate from web.py
         global substract_background,save_background
         global speedx, speedy, restart_translate, average
-        global gamma_divide, gamma_multiply,gamma_setdef,gain_divide,gain_multiply,gain_setdef
+        global gamma_divide, gamma_multiply,gamma_setdef
+        global gain_divide,gain_multiply,gain_setdef
+        global expo_divide,expo_multiply,expo_setdef
+        global timelaps
 
         # print("i... staticmethod frames @ real -  enterred; target_frame==", target_frame)
         senh = Stream_Enhancer()
@@ -101,13 +104,19 @@ class Camera(BaseCamera):
         substract_background = False
         save_background = False
         restart_translate = False
+
         gamma_divide = False
         gamma_multiply =False
         gamma_setdef =False
+
         gain_divide = False
         gain_multiply =False
         gain_setdef =False
 
+        expo_divide = False
+        expo_multiply =False
+        expo_setdef =False
+
         camera = Camera(  )
         cap, vidnum = camera.init_cam(  )
 
@@ -213,11 +222,11 @@ class Camera(BaseCamera):
                         expo_autodef = 3
 
 
-                        # very stupid camera    ZC0303 Webcam - parallel to exposure_auto
+                        # stupid camera ZC0303 Webcam - parallel to exposure_auto
                         if "exposure" in capa:
                             exposure = cc.get_exposure()
 
-                        if "exposure_auto" in capa:  # if not auto, always tell _absolute
+                        if "exposure_auto" in capa: # notauto? alway show _absolute
                             expo_auto = cc.get_exposure_auto()
                             expo_autodef = cc.getdef_exposure_auto()
                             print(f"i... EXPOAUTO == {expo_auto} vs def={expo_autodef}; ")
@@ -241,7 +250,7 @@ class Camera(BaseCamera):
                     if histogram: # just calculate a number on plain frame
                         hmean = senh.histo_mean( )
 
-                    # ---------- before anything - we decode the web command
+                    # ---------- before anything - we decode the web command EXECUTE EXECUTION
                     expression,value = mmread_n_clear( )
                     #print(f"i... expression == {expression}  value == {value}")
                     globals()[expression] = eval(value)
@@ -272,38 +281,58 @@ class Camera(BaseCamera):
                     # average  THIS IS HERE to be changed TOO (ACCUM)
                     # print("i.... average", average)
 
+                    # timelaps  THIS IS HERE to be changed TOO
+                    # print("i.... timelaps", timelaps)
+
                     #print("i... GAMMAS ", gamma, gammadef )
+
                     if gamma_divide:
                         gamma_divide = False
                         if "gamma" in capa:
                             cc.set_gamma( int(gamma/2) )
-
                     if gamma_multiply:
                         gamma_multiply = False
                         if "gamma" in capa:
                             cc.set_gamma( int(gamma*2) )
-
                     if gamma_setdef:
                         gamma_setdef = False
                         if "gamma" in capa:
                             cc.setdef_gamma( )
 
+
                     if gain_divide:
                         gain_divide = False
                         if "gain" in capa:
                             cc.set_gain( int(gain/2) )
-
                     if gain_multiply:
                         gain_multiply = False
                         if "gain" in capa:
                             cc.set_gain( int(gain*2) )
-
                     if gain_setdef:
                         gain_setdef = False
                         if "gain" in capa:
                             cc.setdef_gain( )
 
 
+                    if expo_divide:
+                        expo_divide = False
+                        if "exposure_absolute" in capa:
+                            cc.set_exposure_auto(1)
+                            exposure_absolute = cc.get_exposure_absolute()
+                            cc.set_exposure_absolute( int(exposure_absolute/2) )
+                    if expo_multiply:
+                        expo_multiply = False
+                        if "exposure_absolute" in capa:
+                            cc.set_exposure_auto(1)
+                            exposure_absolute = cc.get_exposure_absolute()
+                            cc.set_exposure_absolute( int(exposure_absolute*2) )
+                    if expo_setdef:
+                        expo_setdef = False
+                        if "exposure_auto" in capa:
+                            cc.setdef_exposure_auto()
+                            cc.setdef_exposure_absolute( )
+
+
                     #--------------- now apply labels ------i cannot get rid in DETM---
                     #--------- all this will be on all rames histo,detect,direct,delta
                     senh.setbox(" ", senh.TIME)
