@@ -26,23 +26,35 @@ class Stream_Enhancer:
     DISP=(0,4) # gree
     MODE=(0,3) # red
 
-    lap= (1,0)
+    # lap   = (1,0)
+    # expo  = (3,0)
+    # gain  = (4,0)
+    # gamma = (5,0)
+    # speedx= (6,0)
+    # speedy= (7,0)
+    lap   = (1,0)
+    expo  = (2,1)
+    gain  = (2,2)
+    gamma = (2,3)
+    speedx= (2,4)
+    speedy= (2,5)
 
-    expo= (3,0) # 3 may be left??
-    gain= (4,0) # 3 may be left??
-    gamma= (5,0) # 3 may be left??
-
-    speedx= (6,0) #
-    speedy= (7,0) #
+    avi = (8,0) #
+    jpg = (9,0) #
 
     #--------------------- 2 is bottom
-    avg= (2,0) #
-    blr= (2,1) #
+    avg= (2,0) # accum
 
-    trh= (2,2) #
-    hist=(2,3)
+    # blr= (2,1) #
+    # trh= (2,2) #
+    # hist=(2,3)
+    # dm=  (2,4) #  it is veeery long
+    blr= (2,0) #
+    trh= (3,0) #
+    hist=(4,0)
     dm=  (2,4) #  it is veeery long
 
+
     delta_frame = None
     detect_frame = None
     frame_area = 1
@@ -71,30 +83,32 @@ class Stream_Enhancer:
 
     def RC_COLOR(self,row,col):
         if not self.frame_ok: return  # B  G R
-        if row==0 and col==0: return (0,0,0)
-        if row==0 and col==3: return (0,0,255) #R
-        if row==0 and col==4: return (0,205,0) #G
+        if (row,col) == self.TIME: return (200,0,0)
+        if (row,col) == self.MODE: return (0,0,255)
+        if (row,col) == self.DISP: return (0,205,0)
 
-        if row==1 and col==0: return (200,100,200) #
+        if (row,col) == self.lap: return (200,100,200) #
         if row==1 and col==1: return (150,150,150) #
         if row==1 and col==2: return (50,50,50) #
         if row==1 and col==3: return (120,120,120) # brown
         if row==1 and col==4: return (180,180,180) # orange
 
-        if row==2 and col==0: return (250,0,0) #
-        if row==2 and col==1: return (150,150,0) #
-        if row==2 and col==2: return (150,0,150) #
-        if row==2 and col==3: return (0,120,150) # brown
-        if row==2 and col==4: return (50,100,250) # orange
+        if (row,col) == self.avg:  return (250,0,0) #
+        if (row,col) == self.blr:  return (150,150,0) #
+        if (row,col) == self.trh:  return (150,0,150) #
+        if (row,col) == self.hist: return (0,120,150) # brown
+        if (row,col) == self.dm:   return (50,100,250) # orange
 
 
         # left side
-        if row==3 and col==0:       return (0,0,0) #
-        if row==4 and col==0:       return (50,50,50) #
-        if row==5 and col==0:       return (80,80,80) #
+        if (row,col) == self.expo:  return (0,0,0) #
+        if (row,col) == self.gain:  return (50,50,50) #
+        if (row,col) == self.gamma: return (80,80,80) #
 
-        if row==6 and col==0:       return (180,80,80) #
-        if row==7 and col==0:       return (80,180,80) #
+        if (row,col) == self.speedx: return (180,80,80) #
+        if (row,col) == self.speedy: return (80,180,80) #
+        if (row,col) == self.avi:    return (30,30,210) # FOR UNI only
+        if (row,col) == self.jpg:    return (0,0,250)   # FOR UNI only
 
         t=[255,255,255]
         while (t[0]+t[1]+t[2]>400) or  (t[0]+t[1]+t[2]<200) :
@@ -146,7 +160,7 @@ class Stream_Enhancer:
             self.frame_ok = False
             return False
         self.frame = image
-        self.maxcol=4
+        self.maxcol=5 # NORMALLY 4
         self.maxrow=14
         # #if fontScale == 0.5
         #if w==320:
@@ -257,7 +271,7 @@ class Stream_Enhancer:
         stretchy = 2.2
         stretchx = 1.3 # this also compensates center-left align?
         pos=[ self.posx_offs, self.posy_offs ]
-        self.get_font_params(" WEB 2.33 ")
+        self.get_font_params(" WEB 2.3, ")
         WIDTH = self.text_width
         self.get_font_params(txt)
 
@@ -278,6 +292,8 @@ class Stream_Enhancer:
 
         if (row==6)and(col==0):  side="left"
         if (row==7)and(col==0):  side="left"
+        if (row==8)and(col==0):  side="left"
+        if (row==9)and(col==0):  side="left"
 
         if side=="" and row>2:
             print("X... Too many rows, (0,1,2 only)")
