@@ -1,6 +1,9 @@
 #!/usr/bin/env python3
 
 # import the necessary packages
+
+#  ls zen_192.168.0.91_20211105_* | while read line; do echo file \'$line\'; done | ffmpeg -protocol_whitelist file,pipe -f concat -i - -c copy zen_192.168.0.91_20211105_.avi
+
 from imutils.video import VideoStream
 import socket
 import time
@@ -30,6 +33,8 @@ import getpass
 
 import sys
 
+from flashcam.stream_enhancer import Stream_Enhancer
+
 @contextmanager
 def timeout(time):
     # register a function to raise a TimeoutError on the signal
@@ -71,11 +76,131 @@ def img_estim(img, thrshld=127):
     return 'light' if is_light else 'dark'
     # 40 -> 2.2
 
+#------------------------------------------------------------------------ 3
+
+def get_stream3( videodev, passfile ):
+    # localuser
+    u,p=getpass.getuser(),"a"
+    try:
+        with open( os.path.expanduser(passfile) ) as f:
+            print("YES---> PASSWORD FILE  ", passfile )
+            w1 = f.readlines()
+            u= w1[0].strip()
+            p= w1[1].strip()
+    except:
+        print("NO PASSWORD FILE  ", passfile)
+        sys.exit(0)
+
+    print("D... capturing from /{}/".format(videodev) )
+    #cam = cv2.VideoCapture( videodev )
+    #stream = urllib.request.urlopen( videodev )
+
+    request = urllib.request.Request( videodev )
+    print("D... USER/PASS", u,p)
+    base64string =base64.b64encode( bytes(  '%s:%s' % (u, p ), 'ascii') )
+    print("D... stream ok1", base64string)
+    request.add_header("Authorization", "Basic %s" % base64string.decode('utf-8'))
+
+    #request.add_header("Authorization", "Basic %s" % base64string)
+    print("D... stream ok2 - request.urlopen (disp)")
+    ok = False
+    stream = None
+    try:
+        stream = urllib.request.urlopen(request, timeout=5)
+        ok = True
+        print("D... stream ok3")
+    except urllib.error.HTTPError as e:
+        print("Server Offline1 ",e)
+        #do stuff here
+    except urllib.error.URLError as e:
+        print("Server Offline2 ",e)
+        #do stuff here
+    except:
+        ok = False
+        stream = None
+        print("X.... Stream from urllib Timeouted OR a bad password")
+    return stream, u, p
 
 
 
 
 
+def display3(videodev, save = False,
+         passfile="~/.pycamfw_userpass"):
+    stream = None
+    if stream is None: # LOGIN
+        stream, u, p = get_stream3(videodev, passfile)
+
+
+    #print(stream)
+
+    ret_val=0
+    oi = 0
+    oi_frame = 0
+    io_none = 0
+    bytex = b''
+    while ret_val == 0:
+        oi+= 1
+        #with timeout(2):
+        got_data = False
+        frameok = False
+
+        try:
+            # THIS CAN TIMEOUT ######################################### i catch
+            bytex += stream.read(1024*40) # i multiply by 10 as later...
+            got_data = True
+        except:
+            print("X... exception - timout in 1.st stream.read, ")
+            #bytex+=b"\x00\x00\x00"
+            #bytex = b""
+
+        a = bytex.find(b'\xff\xd8') #frame starting
+        b = bytex.find(b'\xff\xd9') #frame ending
+
+        #print(f" {len(bytex):7d} {got_data}   {a:8} {b:8}    {b+2-a}")
+
+        if a != -1 and b != -1:
+            io_none = 0
+            jpg = bytex[a:b+2]
+            bytex = bytex[a+2:]
+            bytex = bytex[b+2:]
+            frameok = False
+            try:
+                frame = cv2.imdecode(np.frombuffer(jpg, dtype=np.uint8), cv2.IMREAD_COLOR)
+                #ret_val= 1
+                io_none = 0
+                frameok = True
+            except:
+                ret_val = 0
+
+        else:
+            ret_val = 0
+            #print("D...                        frame set None http",oi,len(bytex), end="\r")
+            #bytex+=b""
+            #time.sleep(0.1)
+            io_none+=1
+            if io_none>30: #max size of jpg
+                stream = None
+                print("X... ---------------   frame not seen too long:", io_none, "... breaking")
+                io_none = 0
+                break
+
+        if (oi_frame % 20) ==0:
+            print("_"*70)
+            print(f"       #     d_size  got      a      b       jpglen frame   f#" )
+            print("_"*70)
+
+        print(f"{oi:8d}  {len(bytex):7d} {got_data}   {a:8} {b:8}    {b+2-a}  {frameok}  {oi_frame}", end = "\n" if frameok else "\r" , flush=True)
+
+        if frameok:
+            oi_frame+= 1
+
+            cv2.imshow( videodev, frame)
+            key = cv2.waitKey(1)
+
+
+
+# ================================================================================================
 
 def display2(videodev, save = False,
          passfile="~/.pycamfw_userpass"):
@@ -106,6 +231,7 @@ def display2(videodev, save = False,
 
     def get_stream():
         # localuser
+        stream = None # i return
         u,p=getpass.getuser(),"a"
         try:
             with open( os.path.expanduser(passfile) ) as f:
@@ -131,20 +257,31 @@ def display2(videodev, save = False,
         print("D... stream ok2 - request.urlopen (disp)")
         ok = False
         try:
-            stream = urllib.request.urlopen(request, timeout=3)
+            stream = urllib.request.urlopen(request, timeout=5)
             ok = True
             print("D... stream ok3")
+        except urllib.error.HTTPError as e:
+            print("Server Offline1? ",e)
+            #do stuff here
+        except urllib.error.URLError as e:
+            print("Server Offline2? ",e)
+            #do stuff here
         except:
             ok = False
             stream = None
-            print("X.... Timeouted")
+            print("X.... Timeouted on URLOPEN")
 
 
         return stream, u, p
 
-
+    io_none = 0 # to reset stream
+    sfilename = ""  # move up to limi # of AVI files.... tst?
+    sfilenamea = ""
+    if save:
+        sfilenamea,saviout = setupsave()
     while True: #==================== MAIN LOOP =================
 
+
         mjpg =False
 
         rpiName = socket.gethostname()
@@ -190,28 +327,52 @@ def display2(videodev, save = False,
             oi = 0
             while ret_val == 0:
                 oi+=1
-                bytex += stream.read(1024)
+
+                #with timeout(2):
+                print("D... IN 1st TIO..", end="")
+                try:
+                    # THIS CAN TIMEOUT #########################################
+                    print("D... try ...", end="")
+                    bytex += stream.read(1024*50) #  must be long enough?
+                except:
+                    print("X... exception - timout in 1.st stream.read, ")
+                    #bytex+=b"\x00\x00\x00"
+                    bytex = b""
+
+
                 a = bytex.find(b'\xff\xd8') #frame starting
                 b = bytex.find(b'\xff\xd9') #frame ending
                 if a != -1 and b != -1:
+                    io_none = 0
                     jpg = bytex[a:b+2]
                     bytex = bytex[b+2:]
                     # frame = cv2.imdecode(np.fromstring(jpg, dtype=np.uint8), cv2.CV_LOAD_IMAGE_COLOR)
-                    frame = cv2.imdecode(np.frombuffer(jpg, dtype=np.uint8), cv2.IMREAD_COLOR)
-                    ret_val= 1
-                    print("D...                ok frame http",oi,len(bytex) )
+                    if len(jpg)>1000:  # was crash here
+                        frame = cv2.imdecode(np.frombuffer(jpg, dtype=np.uint8), cv2.IMREAD_COLOR)
+                        ret_val= 1
+                        io_none = 0
+                    else:
+                        ret_val = 0
+                        # print("D...                ok frame http",oi,len(bytex) )
                 else:
                     ret_val = 0
-                    print("D...          frame set None http",oi,len(bytex), end="\r")
+                    print("D...                        frame set None http",oi,len(bytex), end="\r")
+                    # it can count to milions here.... why? need to check stream ## OTHER CRASHES
+                    #  i try two things now:
+                    #bytex+=b""
+                    time.sleep(0.2)
+                    io_none+=1
+                    if io_none>20:
+                        stream = None
+                        print("X... ---------------  too many unseen frames", io_none, "breaking")
+                        io_none = 0
+                        break
+
                     #frame = None
-
+        if stream is None:
+            continue
 #----------------------------------------------------------------
 
-        sfilename = ""
-        sfilenamea = ""
-        if save:
-            sfilenamea,saviout = setupsave()
-
         first = True
 
         timestamp_of_last_socket_refresh = time.time()
@@ -235,6 +396,9 @@ def display2(videodev, save = False,
         FPS = 0
         FPSlast = 0
 
+        senh = Stream_Enhancer()
+        saved_jpg = False
+
         while connection_ok: #========================================================
             # read the frame from the camera and send it to the server
             #time.sleep(0.05)
@@ -245,18 +409,18 @@ def display2(videodev, save = False,
                 artdelay = 0
                 ret_val = 0
                 try:
-                    with timeout(2):
+                    with timeout(4):
                         while ret_val == 0:
                             for i8 in range(1): # I decimate and remove delay
                                 #print("1-", flush=True,end="")
-                                bytex += stream.read(1024*10)
+                                bytex += stream.read(1024*50)
                                 a = bytex.find(b'\xff\xd8') #frame starting
                                 b = bytex.find(b'\xff\xd9') #frame ending
                                 if a != -1 and b != -1:
-                                    BPS+=len(bytex)/1024
-                                    if len(bytex)>0:
-                                        FPS+=1
                                     jpg = bytex[a:b+2]
+                                    BPS+=len(jpg)/1024
+                                    if len(jpg)>0:
+                                        FPS+=1
                                     bytex = bytex[b+2:]
                                     frame = cv2.imdecode(np.frombuffer(jpg, dtype=np.uint8), cv2.IMREAD_COLOR)
                                     ret_val=1
@@ -308,10 +472,20 @@ def display2(videodev, save = False,
                 cv2.namedWindow( wname, cv2.WINDOW_KEEPRATIO)
                 cv2.resizeWindow(wname, frame.shape[1], frame.shape[0] )
 
-                cv2.imshow(rpi_name, frame) # 1 window for each RPi
                 if save:
+                    # print("AVI")
                     saviout.write(frame)
+                    if senh.add_frame(frame):
+                        # print("avi..")
+                        senh.setbox(f"AVI",  senh.avi)
+                        frame = senh.get_frame(  )
+                if saved_jpg:
+                    if senh.add_frame(frame):
+                        # print("avi..")
+                        senh.setbox(f"JPG",  senh.jpg)
+                        frame = senh.get_frame(  )
 
+                cv2.imshow(rpi_name, frame) # 1 window for each RPi
                 # time.sleep(0.2)
                 key = cv2.waitKey(1)
 
@@ -329,9 +503,12 @@ def display2(videodev, save = False,
                 if (not frame is None) and (rpi_name!="") and (key == ord('q')):
                     print("Q PRESSED!")
                     sys.exit(1)
+
+                saved_jpg = False
                 if (not frame is None) and (rpi_name!="") and (key == ord('s')):
                     print("S PRESSED!")
                     sname = "snapshot"
+                    saved_jpg = True
                     sfilename = dt.datetime.now().strftime("%Y%m%d_%H%M%S")
                     sme = socket.gethostname()
                     sfilename = f"{sme}{sname}_{sfilename}.jpg"
@@ -347,5 +524,5 @@ def display2(videodev, save = False,
 
 
 if __name__=="__main__":
-    Fire( display2)
+    Fire( display3)
     #Fire({ "disp":display2,   "disp2":display2    })
